@@ -30,7 +30,7 @@
 #include <krandomsequence.h>
 #include <kfilterdev.h>
 #include <klocalizedstring.h>
-#include "autosave/kautosavefile.h"
+#include <kautosavefile.h>
 
 #include "keduvocexpression.h"
 #include "keduvoclesson.h"
@@ -49,8 +49,6 @@
 #define TXT_EXT          "txt"
 #define WQL_EXT          "wql"
 
-using namespace LexiAutoSave;
-
 /** @details Private Data class for KEduVocDocument */
 class KEduVocDocument::KEduVocDocumentPrivate
 {
@@ -62,7 +60,7 @@ public:
         m_lessonContainer = 0;
         m_wordTypeContainer = 0;
         m_leitnerContainer = 0;
-        m_autosave = new LexiAutoSave::KAutoSaveFile;
+        m_autosave = new KAutoSaveFile;
         init();
     }
 
@@ -78,7 +76,7 @@ public:
      * Note: It is a pointer to allow locking a new file, saving results and
      * then transfering the lock to m_autosave without risking loss of lock.
      * See saveAs for clarification*/
-    LexiAutoSave::KAutoSaveFile            *m_autosave;
+    KAutoSaveFile            *m_autosave;
 
     bool                      m_dirty;                ///< dirty bit
     bool                      m_isReadOnly;	      ///< FileOpenReadOnly was used for opening
@@ -159,7 +157,7 @@ void KEduVocDocument::KEduVocDocumentPrivate::init()
     m_isReadOnly = false;
     m_queryorg = "";
     m_querytrans = "";
-    m_autosave->setManagedFile( i18n( "Untitled" ) );
+    m_autosave->setManagedFile( QUrl() );
     m_author = "";
     m_title = "";
     m_comment = "";
@@ -174,7 +172,7 @@ void KEduVocDocument::KEduVocDocumentPrivate::init()
 
 KEduVocDocument::ErrorCode KEduVocDocument::KEduVocDocumentPrivate::initializeKAutoSave(KAutoSaveFile &autosave,  QString const & fpath,  FileHandlingFlags flags) const {
 
-    QList<KAutoSaveFile *> staleFiles = KAutoSaveFile::staleFiles( fpath,
+    QList<KAutoSaveFile *> staleFiles = KAutoSaveFile::staleFiles( QUrl::fromLocalFile(fpath),
                                                                  QCoreApplication::instance()->applicationName());
     if ( !staleFiles.isEmpty()) {
         if ( flags & FileIgnoreLock ) {
@@ -189,7 +187,7 @@ KEduVocDocument::ErrorCode KEduVocDocument::KEduVocDocumentPrivate::initializeKA
         }
     }
 
-    autosave.setManagedFile( fpath );
+    autosave.setManagedFile( QUrl::fromLocalFile(fpath) );
     if ( !autosave.open( QIODevice::ReadWrite ) ) {
         qWarning() << i18n( "Cannot lock file %1", autosave.fileName() );
         return FileCannotLock;
@@ -256,9 +254,9 @@ KEduVocDocument::ErrorCode KEduVocDocument::open( const QUrl& url, FileHandlingF
             qWarning() << i18n("Cannot open tempfile %1",  tempFile.fileName());
             return Unknown;
         }
-        KIO::FileCopyJob *job = KIO::file_copy(url, tempFile.fileName());
+        KIO::FileCopyJob *job = KIO::file_copy(url, QUrl::fromLocalFile(tempFile.fileName()), -1, KIO::Overwrite);
         if (!job->exec()) {
-            qWarning() << i18n("Cannot download %1",  url.toDisplayString());
+            qWarning() << i18n("Cannot download %1: %2",  url.toDisplayString(), job->errorString());
             return FileDoesNotExist;
         }
         temporaryFile = tempFile.fileName();
